# Generated by Django 3.2 on 2022-12-20 07:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0037_alter_leavetype_total'),
    ]

    operations = [
        migrations.AlterField(
            model_name='leavetype',
            name='total',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
