# Generated by Django 4.0 on 2022-09-25 00:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0015_alter_leavede_obs_alter_leavedelegate_obs_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='leave',
            name='is_print',
            field=models.BooleanField(default=False, null=True),
        ),
    ]
