# Generated by Django 3.2 on 2022-12-10 15:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0026_auto_20221210_2356'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='leave',
            name='end_datetime',
        ),
        migrations.RemoveField(
            model_name='leave',
            name='start_datetime',
        ),
    ]
