# Generated by Django 3.2 on 2022-12-17 06:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0033_leave_pr_confirm'),
    ]

    operations = [
        migrations.RenameField(
            model_name='leave',
            old_name='pr_confirm',
            new_name='pr_approve',
        ),
    ]
