# Generated by Django 4.0 on 2022-09-23 01:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('employee', '0004_employee_emp_id'),
        ('leave', '0002_remove_taskdelegate_date'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='TaskDelegate',
            new_name='LeaveDelegate',
        ),
    ]
