# Generated by Django 4.0 on 2022-09-23 13:19

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0011_remove_leave_de_obs_remove_leave_hr_obs_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='leavedelegate',
            name='leave',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='leavedelegate', to='leave.leave'),
        ),
        migrations.AlterField(
            model_name='leaveunit',
            name='leave',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='leaveunit', to='leave.leave'),
        ),
    ]
