# Generated by Django 4.0 on 2022-09-23 05:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0004_alter_leavedelegate_employee'),
    ]

    operations = [
        migrations.RenameField(
            model_name='leavedelegate',
            old_name='is_approve',
            new_name='is_confirm',
        ),
    ]
