# Generated by Django 3.2 on 2023-01-22 06:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0063_leave_is_done'),
    ]

    operations = [
        migrations.AddField(
            model_name='leave',
            name='pr_send',
            field=models.BooleanField(default=False, null=True),
        ),
    ]
