# Generated by Django 4.0 on 2022-09-23 13:46

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('leave', '0013_leave_is_finish'),
    ]

    operations = [
        migrations.CreateModel(
            name='LeaveHR',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('obs', models.CharField(blank=True, choices=[('Sim', 'Sim'), ('Lae', 'Lae')], max_length=3, null=True, verbose_name='Observasaun')),
                ('reason', models.TextField(blank=True, null=True, verbose_name='Rajaun')),
                ('datetime', models.DateTimeField(null=True)),
                ('hashed', models.CharField(max_length=32, null=True)),
                ('leave', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='leavehr', to='leave.leave')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='auth.user')),
            ],
        ),
        migrations.CreateModel(
            name='LeaveDE',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('obs', models.CharField(blank=True, choices=[('Sim', 'Sim'), ('Lae', 'Lae')], max_length=3, null=True, verbose_name='Observasaun')),
                ('reason', models.TextField(blank=True, null=True, verbose_name='Rajaun')),
                ('datetime', models.DateTimeField(null=True)),
                ('hashed', models.CharField(max_length=32, null=True)),
                ('leave', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='leavede', to='leave.leave')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='auth.user')),
            ],
        ),
    ]
