from django.contrib import admin
from .models import *

admin.site.register(LeaveType)
admin.site.register(Leave)
admin.site.register(LeaveCount)
admin.site.register(LeaveDelegate)
admin.site.register(LeaveUnit)
admin.site.register(LeaveHR)
admin.site.register(LeaveDE)
admin.site.register(LeaveDep)
admin.site.register(Year)
admin.site.register(Month)
admin.site.register(LeavePeriod)