# Generated by Django 3.2 on 2022-12-10 17:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0027_auto_20221211_0022'),
    ]

    operations = [
        migrations.AddField(
            model_name='leave',
            name='end_datetime',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='leave',
            name='start_datetime',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
