# Generated by Django 3.2 on 2022-12-29 17:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0056_auto_20221230_0221'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='leavecount',
            options={},
        ),
    ]
