# Generated by Django 3.2 on 2023-01-14 03:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0060_leavecount_update_date'),
    ]

    operations = [
        migrations.AddField(
            model_name='leavecount',
            name='balance_month',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Balance Month'),
        ),
    ]
