# Generated by Django 3.2 on 2022-12-21 01:09

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0048_auto_20221221_1008'),
    ]

    operations = [
        migrations.AddField(
            model_name='leavecount',
            name='month',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='leavecountmonth', to='leave.month', verbose_name='Fulan'),
        ),
        migrations.AddField(
            model_name='leavecount',
            name='year',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='leavecountyear', to='leave.year', verbose_name='Tinan'),
        ),
    ]
