# Generated by Django 3.2 on 2022-12-21 01:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0047_auto_20221220_1729'),
    ]

    operations = [
        migrations.AddField(
            model_name='leavecount',
            name='leave_earn',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Leave Earn'),
        ),
        migrations.AddField(
            model_name='leavecount',
            name='total_balance',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Total Balance'),
        ),
        migrations.AddField(
            model_name='leavecount',
            name='total_earn',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Total Earn'),
        ),
        migrations.AlterField(
            model_name='leavecount',
            name='balance',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Balance'),
        ),
        migrations.AlterField(
            model_name='leavecount',
            name='taken',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Taken'),
        ),
        migrations.AlterField(
            model_name='leavecount',
            name='total',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Total Taken'),
        ),
    ]
