# Generated by Django 3.2 on 2023-03-13 10:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0070_leave_is_create_by_hr'),
    ]

    operations = [
        migrations.AddField(
            model_name='leave',
            name='end_time_status',
            field=models.CharField(blank=True, choices=[('12:00', '12:00'), ('17:00', '17:00')], max_length=15, null=True, verbose_name='Horas Remata Licensa'),
        ),
        migrations.AddField(
            model_name='leave',
            name='start_time_status',
            field=models.CharField(blank=True, choices=[('08:00', '08:00'), ('13:00', '13:00')], max_length=15, null=True, verbose_name='Horas Hahu Licensa'),
        ),
    ]
