<div class="card-body">
    <div class="row">
        <div class="col-md-12">
            <span class="alert alert-danger">{{message|safe}}</span>
            <hr/>
        </div><!--end col-->
    </div><!--end row-->
</div> 