# Generated by Django 4.0 on 2022-09-25 04:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0020_remove_leave_s_is_delegate'),
    ]

    operations = [
        migrations.AddField(
            model_name='leave',
            name='is_approve',
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AddField(
            model_name='leave',
            name='is_reject',
            field=models.BooleanField(default=False, null=True),
        ),
    ]
