# Generated by Django 4.0 on 2022-10-02 12:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0023_remove_leavedelegate_is_send'),
    ]

    operations = [
        migrations.AlterField(
            model_name='leave',
            name='is_active',
            field=models.BooleanField(default=True, null=True),
        ),
    ]
