# Generated by Django 4.0 on 2022-09-25 10:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0022_rename_s_is_finish_leave_is_delegate_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='leavedelegate',
            name='is_send',
        ),
    ]
