# Generated by Django 4.0 on 2022-09-21 12:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='taskdelegate',
            name='date',
        ),
    ]
