# Generated by Django 3.2 on 2022-12-26 14:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0054_auto_20221225_2232'),
    ]

    operations = [
        migrations.AddField(
            model_name='leave',
            name='description',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Deskrisaun Licensa'),
        ),
    ]
