# Generated by Django 4.0 on 2022-09-25 02:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0017_remove_leavecount_datetime_remove_leavecount_hashed_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='leavecount',
            name='balance',
            field=models.IntegerField(blank=True, null=True, verbose_name='Balansu'),
        ),
    ]
