# Generated by Django 3.2 on 2022-12-11 02:51

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('leave', '0028_auto_20221211_0202'),
    ]

    operations = [
        migrations.CreateModel(
            name='LeaveDep',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('obs', models.CharField(blank=True, choices=[('Sim', 'Sim'), ('Lae', 'Lae')], max_length=3, null=True, verbose_name='Aprova')),
                ('reason', models.TextField(blank=True, null=True, verbose_name='Rajaun')),
                ('datetime', models.DateTimeField(null=True)),
                ('hashed', models.CharField(max_length=32, null=True)),
                ('leave', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='leavedep', to='leave.leave')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
