# Generated by Django 4.0 on 2022-09-25 03:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0019_leave_s_is_delegate'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='leave',
            name='s_is_delegate',
        ),
    ]
