# Generated by Django 4.0 on 2022-09-23 05:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0007_leavetype_total'),
    ]

    operations = [
        migrations.RenameField(
            model_name='leave',
            old_name='de_confirm',
            new_name='de_approve',
        ),
        migrations.RenameField(
            model_name='leave',
            old_name='dep_confirm',
            new_name='hr_confirm',
        ),
        migrations.RenameField(
            model_name='leave',
            old_name='dep_send',
            new_name='hr_send',
        ),
    ]
