# Generated by Django 4.0 on 2022-09-25 00:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0014_leavehr_leavede'),
    ]

    operations = [
        migrations.AlterField(
            model_name='leavede',
            name='obs',
            field=models.CharField(blank=True, choices=[('Sim', 'Sim'), ('Lae', 'Lae')], max_length=3, null=True, verbose_name='Aprova'),
        ),
        migrations.AlterField(
            model_name='leavedelegate',
            name='obs',
            field=models.CharField(blank=True, choices=[('Sim', 'Sim'), ('Lae', 'Lae')], max_length=3, null=True, verbose_name='Simu Delegasaun'),
        ),
        migrations.AlterField(
            model_name='leavehr',
            name='obs',
            field=models.CharField(blank=True, choices=[('Sim', 'Sim'), ('Lae', 'Lae')], max_length=3, null=True, verbose_name='Certifica'),
        ),
        migrations.AlterField(
            model_name='leaveunit',
            name='obs',
            field=models.CharField(blank=True, choices=[('Sim', 'Sim'), ('Lae', 'Lae')], max_length=3, null=True, verbose_name='Aprova'),
        ),
    ]
