# Generated by Django 4.0 on 2022-09-23 05:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0005_rename_is_approve_leavedelegate_is_confirm'),
    ]

    operations = [
        migrations.AddField(
            model_name='leavedelegate',
            name='is_confirm2',
            field=models.BooleanField(default=False, null=True),
        ),
    ]
