# Generated by Django 4.0 on 2022-09-23 06:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0008_rename_de_confirm_leave_de_approve_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='leave',
            old_name='is_lock',
            new_name='s_is_finish',
        ),
        migrations.RenameField(
            model_name='leave',
            old_name='is_send',
            new_name='s_is_lock',
        ),
        migrations.AddField(
            model_name='leave',
            name='s_is_send',
            field=models.BooleanField(default=False, null=True),
        ),
    ]
