# Generated by Django 3.2 on 2022-12-25 13:32

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0053_leavecount_total_taken'),
    ]

    operations = [
        migrations.AddField(
            model_name='leavecount',
            name='period',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='leaveperiodcount', to='leave.leaveperiod'),
        ),
        migrations.AlterField(
            model_name='leavecount',
            name='total',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Total'),
        ),
    ]
