# Generated by Django 4.0 on 2022-09-25 08:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0021_leave_is_approve_leave_is_reject'),
    ]

    operations = [
        migrations.RenameField(
            model_name='leave',
            old_name='s_is_finish',
            new_name='is_delegate',
        ),
        migrations.RenameField(
            model_name='leave',
            old_name='s_is_lock',
            new_name='is_lock',
        ),
        migrations.RenameField(
            model_name='leave',
            old_name='s_is_send',
            new_name='is_send',
        ),
    ]
