# Generated by Django 3.2 on 2023-03-13 14:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0072_auto_20230313_2331'),
    ]

    operations = [
        migrations.AlterField(
            model_name='leave',
            name='end_time_status',
            field=models.CharField(blank=True, choices=[('PM:12:00', 'PM:12:00'), ('PM:17:00', 'PM:17:00')], max_length=15, null=True, verbose_name='Horas Remata Licensa'),
        ),
        migrations.AlterField(
            model_name='leave',
            name='start_time_status',
            field=models.CharField(blank=True, choices=[('AM-08:00', 'AM-08:00'), ('PM:13:00', 'PM:13:00')], max_length=15, null=True, verbose_name='Horas Hahu Licensa'),
        ),
    ]
