# Generated by Django 3.2 on 2023-01-18 02:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0061_leavecount_balance_month'),
    ]

    operations = [
        migrations.AddField(
            model_name='leavehr',
            name='comment',
            field=models.TextField(blank=True, null=True, verbose_name='Komentario'),
        ),
    ]
