# Generated by Django 3.2 on 2022-12-17 07:14

import django.core.validators
from django.db import migrations, models
import settings_app.upload_utils


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0034_rename_pr_confirm_leave_pr_approve'),
    ]

    operations = [
        migrations.AddField(
            model_name='leave',
            name='file',
            field=models.FileField(blank=True, null=True, upload_to=settings_app.upload_utils.upload_leave, validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])], verbose_name='Upload Anekso'),
        ),
    ]
