# Generated by Django 3.2 on 2022-12-29 17:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0055_leave_description'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='leavecount',
            options={'ordering': ('pk', 'year')},
        ),
        migrations.AddField(
            model_name='leavecount',
            name='last_total_balance',
            field=models.DecimalField(blank=True, decimal_places=2, default=0.0, max_digits=5, null=True, verbose_name='Last Total Balance'),
        ),
    ]
