# Generated by Django 4.0 on 2022-09-23 13:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0009_rename_is_lock_leave_s_is_finish_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='leave',
            name='de_obs',
            field=models.CharField(blank=True, choices=[('Sim', 'Sim'), ('Lae', 'Lae')], max_length=3, null=True, verbose_name='Observasaun'),
        ),
        migrations.AddField(
            model_name='leave',
            name='hr_obs',
            field=models.CharField(blank=True, choices=[('Sim', 'Sim'), ('Lae', 'Lae')], max_length=3, null=True, verbose_name='Observasaun'),
        ),
        migrations.AddField(
            model_name='leave',
            name='unit_obs',
            field=models.CharField(blank=True, choices=[('Sim', 'Sim'), ('Lae', 'Lae')], max_length=3, null=True, verbose_name='Observasaun'),
        ),
    ]
