# Generated by Django 3.2 on 2023-01-10 05:27

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('employee', '0019_employee_ext'),
        ('leave', '0057_alter_leavecount_options'),
    ]

    operations = [
        migrations.AddField(
            model_name='leaveperiod',
            name='employee',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='leaveperiod', to='employee.employee'),
        ),
    ]
