# Generated by Django 3.2 on 2022-12-25 12:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0051_alter_leavecount_taken'),
    ]

    operations = [
        migrations.AddField(
            model_name='leavecount',
            name='prov_total_earn',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Provision Total Earn'),
        ),
    ]
