# Generated by Django 3.2 on 2022-12-10 14:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0024_alter_leave_is_active'),
    ]

    operations = [
        migrations.AddField(
            model_name='leave',
            name='end_date_status',
            field=models.CharField(blank=True, choices=[('Dader', 'Dader'), ('Lokraik', 'Lokraik')], max_length=15, null=True, verbose_name='Horas Data Remata'),
        ),
        migrations.AddField(
            model_name='leave',
            name='start_date_status',
            field=models.CharField(blank=True, choices=[('Dader', 'Dader'), ('Lokraik', 'Lokraik')], max_length=15, null=True, verbose_name='Horas Data Hahu'),
        ),
    ]
