# Generated by Django 3.2 on 2023-02-02 00:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0067_leave_is_send_to_div'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='leave',
            name='end_datetime',
        ),
        migrations.RemoveField(
            model_name='leave',
            name='start_datetime',
        ),
        migrations.AddField(
            model_name='leave',
            name='end_time',
            field=models.TimeField(blank=True, null=True, verbose_name='Horas Remata'),
        ),
        migrations.AddField(
            model_name='leave',
            name='start_time',
            field=models.TimeField(blank=True, null=True, verbose_name='Horas Hahu'),
        ),
    ]
