# Generated by Django 3.2 on 2022-12-20 08:29

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0046_month_year'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='month',
            name='is_active',
        ),
        migrations.RemoveField(
            model_name='year',
            name='is_active',
        ),
        migrations.CreateModel(
            name='LeavePeriod',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.BooleanField(default=False)),
                ('end_month', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='end_month', to='leave.month', verbose_name='Fulan Remata')),
                ('end_year', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='end_year', to='leave.year', verbose_name='Tinan Remata')),
                ('start_month', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='start_month', to='leave.month', verbose_name='Fulan Hahu')),
                ('start_year', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='start_year', to='leave.year', verbose_name='Tinan Hahu')),
            ],
        ),
        migrations.AddField(
            model_name='leave',
            name='leave_period',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='leaveperiod', to='leave.leaveperiod', verbose_name='Leave Period'),
        ),
    ]
