# Generated by Django 4.0 on 2022-09-23 01:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('employee', '0004_employee_emp_id'),
        ('leave', '0003_rename_taskdelegate_leavedelegate'),
    ]

    operations = [
        migrations.AlterField(
            model_name='leavedelegate',
            name='employee',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='leavedelegate', to='employee.employee', verbose_name='Delega ba'),
        ),
    ]
