# Generated by Django 3.2 on 2023-01-13 15:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0059_auto_20230110_1535'),
    ]

    operations = [
        migrations.AddField(
            model_name='leavecount',
            name='update_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]
