# Generated by Django 3.2 on 2023-01-10 06:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0058_leaveperiod_employee'),
    ]

    operations = [
        migrations.AddField(
            model_name='leaveperiod',
            name='end_date',
            field=models.DateField(blank=True, null=True, verbose_name='Data Remate'),
        ),
        migrations.AddField(
            model_name='leaveperiod',
            name='start_date',
            field=models.DateField(blank=True, null=True, verbose_name='Data Hahu'),
        ),
    ]
