# Generated by Django 3.2 on 2022-12-21 02:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0049_auto_20221221_1009'),
    ]

    operations = [
        migrations.AddField(
            model_name='leavecount',
            name='total_balance_leave',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Total Balance Leave'),
        ),
    ]
